// file      : tests/driver/driver.cxx
// author    : Boris Kolpackov <boris@codesynthesis.com>
// copyright : Copyright (c) 2006 Code Synthesis Tools CC
// license   : GNU GPL v2 + exceptions; see accompanying LICENSE file

#include <cult/types.hxx>

#include <xsd-frontend/parser.hxx>

#include <iostream>

using namespace Cult::Types;
using namespace XSDFrontend;

using std::wcerr;
using std::endl;

Int
main (Int argc, Char* argv[])
{
  try
  {
    if (argc < 2)
    {
      wcerr << argv[0] << ": error: no input file." << endl;
      return 1;
    }

    // Parse schema.
    //
    SemanticGraph::Path tu (argv[1], boost::filesystem::native);

    Parser parser;
    Evptr<SemanticGraph::Schema> schema (parser.parse (tu));

    return 0;
  }
  catch (InvalidSchema const&)
  {
    // Diagnostic has already been issued.
  }
  catch (SemanticGraph::InvalidPath const&)
  {
    wcerr << argv[0] << ": error: '" << argv[1] << "' is not a valid "
      << "filesystem path" << endl;
  }

  return 1;
}
